@@ -8,7 +8,7 @@ class Parser:
 
     def __init__(self, config: Config, headless: bool=True, window: dict={}) -> None:
         self.config = config
-        self.scraper = self.get_scraper(headless=headless, window=window)
+        self.scraper = self.get_scraper(config=config, headless=headless, window=window)
 
     # region methods
     def click(self, path: str, element: any=None, timeout: int=0) -> any:
@@ -61,7 +61,7 @@ class Parser:
 
     #endregion methods
 
-    def get_scraper(self, headless: bool=True, window: dict={}) -> Scraper:
+    def get_scraper(self, config: Config, headless: bool=True, window: dict={}) -> Scraper:
         scraper_type = self.config.get('PROJECT', 'scraper')
         if scraper_type is not None:
             module_name = self.config.get('PROJECT', 'scraper')
@@ -70,4 +70,4 @@ class Parser:
             module_name = 'selenium'
             class_name = 'Selenium'
 
-        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'window': window })
\ No newline at end of file
+        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'window': window, 'config': config })
\ No newline at end of file
